@@ -3,8 +3,9 @@ from PyObjCTools.TestSupport import *
 from QTKit import *
 
 class TestQTCaptureDecompressedVideoOutput (TestCase):
-    def testInformalProtocols(self):
-        self.assertIsInstance(protocols.QTCaptureDecompressedVideoOutput_Delegate, objc.informal_protocol)
+    #def testInformalProtocols(self):
+        #self.assertIsInstance(protocols.QTCaptureDecompressedVideoOutput_Delegate, objc.informal_protocol)
+    pass
 
 if __name__ == "__main__":
     main()
