@@ -6,8 +6,8 @@ class TestQTCaptureView (TestCase):
     def testMethods(self):
         self.assertResultIsBOOL(QTCaptureView.preservesAspectRatio)
 
-    def testProtocols(self):
-        self.assertIsInstance(protocols.QTCaptureView_Delegate, objc.informal_protocol)
+    #def testProtocols(self):
+    #    self.assertIsInstance(protocols.QTCaptureView_Delegate, objc.informal_protocol)
 
 if __name__ == "__main__":
     main()
