@@ -2,6 +2,11 @@
 from PyObjCTools.TestSupport import *
 from QTKit import *
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestQTTrack (TestCase):
     def testConstants(self):
         self.assertIsInstance(QTTrackBoundsAttribute, unicode)
